"use strict";

/**
 * The reducer registry manages the initial and future register process of reducers.
 * It enables lazy loading of reducers by implementing a state-saving replacement of the
 * store reducer.
 *
 * The idea and source code was originally written by the DEV team at Twitter, see this post:
 * http://nicolasgallagher.com/redux-modules-and-code-splitting/
 *
 * @export
 */
class ReducerRegistry {
    constructor() {
        this._emitChange = null;
        this._reducers = {};
    }
    getReducers() {
        return Object.assign({}, this._reducers);
    }
    register(name, reducer) {
        this._reducers = Object.assign({}, this._reducers, { [name]: reducer });
        if (this._emitChange) {
            this._emitChange(this.getReducers());
        }
    }
    setChangeListener(listener) {
        this._emitChange = listener;
    }
}
exports.ReducerRegistry = ReducerRegistry;
const reducerRegistry = exports.reducerRegistry = new ReducerRegistry();